@@ -45,7 +45,7 @@ def FindERG(data, depth=2, sort_num=20, verbose=False, figure=False):
     if len(data.columns)<=2:
         print('the number of samples must larger than 2')
         return
-    if depth>(len(data.columns)-1):
+    if depth>(len(data.columns)):
         print('depth larger than samples')
         return
     count=0
